summaryrefslogtreecommitdiff
path: root/utility/include
diff options
context:
space:
mode:
authorGaurav Shah <gauravsh@chromium.org>2010-05-27 13:29:20 -0700
committerGaurav Shah <gauravsh@chromium.org>2010-05-27 13:29:20 -0700
commitb85b06bb25dc4f55aedb0cb7f71c0b1b01ef7b66 (patch)
tree2e8a1d5e7cbb8d6f1203373772fcbafd3a60f1ad /utility/include
parentd6ff721eb077759ac8f672dc15094e65968bc45e (diff)
downloadvboot-b85b06bb25dc4f55aedb0cb7f71c0b1b01ef7b66.tar.gz
Add a --subkey switch to kernel signing utility.
This option makes the signing utility just output the kernel subkey (key signature) header which can be used to generate subsequent signed kernel images without needing the firmware root key and using the same kernel signing key. (This feature will be a part of a subsequent CL). Review URL: http://codereview.chromium.org/2310002
Diffstat (limited to 'utility/include')
-rw-r--r--utility/include/kernel_utility.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/utility/include/kernel_utility.h b/utility/include/kernel_utility.h
index 1d03685a..66802cf3 100644
--- a/utility/include/kernel_utility.h
+++ b/utility/include/kernel_utility.h
@@ -77,7 +77,8 @@ class KernelUtility {
bool is_generate_; // Are we generating a new image?
bool is_verify_; // Are we just verifying an already signed image?
bool is_describe_; // Should we print out description of the image?
- bool is_only_vblock_; // Show we just output the verification block?
+ bool is_only_vblock_; // Should we just output the verification block?
+ bool is_subkey_out_; // Should we just output the subkey header?
};
} // namespace vboot_reference